@@ -17,13 +17,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * Contact roland@cpan.org for any licensing questions.
+ * A commercial license is available as well. Please contact roland@cpan.org for
+ * further details.
  */
 
 package org.cpan.jmx4perl.converter;
 
 import org.json.simple.JSONArray;
 
+import javax.management.AttributeNotFoundException;
 import java.lang.reflect.Array;
 import java.util.List;
 import java.util.Stack;
@@ -39,7 +41,7 @@ public class ArrayHandler implements AttributeToJsonConverter.Handler {
         return null;
     }
 
-    public Object handle(AttributeToJsonConverter pConverter, Object pValue, Stack<String> pExtraArgs) {
+    public Object handle(AttributeToJsonConverter pConverter, Object pValue, Stack<String> pExtraArgs) throws AttributeNotFoundException {
         int length = Array.getLength(pValue);
         if (!pExtraArgs.isEmpty()) {
             Object obj = Array.get(pValue, Integer.parseInt(pExtraArgs.pop()));
