@@ -17,13 +17,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * Contact roland@cpan.org for any licensing questions.
+ * A commercial license is available as well. Please contact roland@cpan.org for
+ * further details.
  */
 
 package org.cpan.jmx4perl.converter;
 
 import org.json.simple.JSONArray;
 
+import javax.management.AttributeNotFoundException;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
@@ -39,7 +41,7 @@ public class CollectionHandler implements AttributeToJsonConverter.Handler {
         return Collection.class;
     }
 
-    public Object handle(AttributeToJsonConverter pConverter, Object pValue, Stack<String> pExtraArgs) {
+    public Object handle(AttributeToJsonConverter pConverter, Object pValue, Stack<String> pExtraArgs) throws AttributeNotFoundException {
         Collection list = (Collection) pValue;
         List ret = null;
         Iterator it = list.iterator();
