@@ -17,7 +17,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * Contact roland@cpan.org for any licensing questions.
+ * A commercial license is available as well. Please contact roland@cpan.org for
+ * further details.
  */
 
 package org.cpan.jmx4perl.converter;
@@ -25,6 +26,8 @@ package org.cpan.jmx4perl.converter;
 import org.json.simple.JSONObject;
 
 import javax.management.openmbean.CompositeData;
+import javax.management.openmbean.InvalidKeyException;
+import javax.management.AttributeNotFoundException;
 import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
 import java.util.Stack;
@@ -41,15 +44,18 @@ public class CompositeHandler implements AttributeToJsonConverter.Handler {
     }
 
     public Object handle(AttributeToJsonConverter pConverter, Object pValue,
-                         Stack<String> pExtraArgs) {
+                         Stack<String> pExtraArgs) throws AttributeNotFoundException {
         CompositeData cd = (CompositeData) pValue;
 
         if (!pExtraArgs.isEmpty()) {
+            String decodedKey = "";
             try {
-                String decodedKey = URLDecoder.decode(pExtraArgs.pop(), "UTF-8");
+                decodedKey = URLDecoder.decode(pExtraArgs.pop(), "UTF-8");
                 return pConverter.prepareForJson(cd.get(decodedKey),pExtraArgs);
             } catch (UnsupportedEncodingException exp) {
                 throw new RuntimeException("Internal: Encoding UTF-8 not supported");
+            }  catch (InvalidKeyException exp) {
+                throw new AttributeNotFoundException("Invalid path '" + decodedKey + "'");
             }
         } else {
             JSONObject ret = new JSONObject();
