@@ -17,7 +17,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * Contact roland@cpan.org for any licensing questions.
+ * A commercial license is available as well. Please contact roland@cpan.org for
+ * further details.
  */
 
 package org.cpan.jmx4perl.converter;
@@ -37,6 +38,6 @@ public class PlainValueHandler implements AttributeToJsonConverter.Handler {
     public Object handle(AttributeToJsonConverter pConverter, Object pValue, Stack pExtraArgs) {
         // TODO: Check extra args for an expression which should be applied to the
         // value object to get the 'real' value.
-        return pValue;
+        return pValue.toString();
     }
 }
