@@ -29,15 +29,11 @@ sub order {
     return 10;
 }
 
-sub __try_version {
+sub _try_version {
     my $self = shift;
     return $self->try_attribute("version","jonas:j2eeType=J2EEServer,name=jonas","serverVersion");
 }
 
-sub autodetect_pattern {
-    return ("vendor",qr/OW2/i);
-}
-
 sub server_info { 
     my $self = shift;
     my $ret = $self->SUPER::server_info();
@@ -54,7 +50,7 @@ sub init_aliases {
      attributes => 
    {
     #SERVER_ADDRESS => [ "jboss.system:type=ServerInfo", "HostAddress"],
-    #SERVER_HOSTNAME => [ "jonas:name=jonas,type=ServerProxy", "HostName"],
+    SERVER_HOSTNAME => [ "jonas:name=jonas,type=ServerProxy", "HostName"],
    },
      operations => 
    {
