@@ -2,7 +2,6 @@
 package JMX::Jmx4Perl::Product::Weblogic;
 
 use JMX::Jmx4Perl::Product::BaseHandler;
-use JMX::Jmx4Perl::Request;
 use strict;
 use base "JMX::Jmx4Perl::Product::BaseHandler";
 
@@ -14,8 +13,8 @@ JMX::Jmx4Perl::Product::Weblogic - Handler for Oracle WebLogic
 
 =head1 DESCRIPTION
 
-This is the product handler support for Oracle Weblogic Server 9 and 10 
-(L<http://www.oracle.com/appserver/>)
+This is the product handler support for Oracle Weblogic Server 10 (9 might
+work, but is not tested) (L<http://www.oracle.com/appserver/>)
 
 =cut
 
@@ -39,16 +38,11 @@ sub _try_version {
     return $self->try_attribute("version",$self->{server_domain},"ConfigurationVersion");
 }
 
-sub vendor {
-    return "Oracle";
-}
-
 sub server_info { 
     my $self = shift;
     my $ret = $self->SUPER::server_info();
     $ret .= sprintf("%-10.10s %s\n","IP:",$self->{jmx4perl}->get_attribute("SERVER_ADDRESS"));
 }
-
 sub _try_server_domain {
     my $self = shift;
     return $self->try_attribute
@@ -58,11 +52,7 @@ sub _try_server_domain {
 }
 
 sub jsr77 {
-    return 0;
-}
-
-sub autodetect_pattern {
-    return ("version",1);
+    return 1;
 }
 
 sub init_aliases {
@@ -82,24 +72,12 @@ sub init_aliases {
      operations => {
                     # Needs to be done in a more complex. Depends on admin server name *and*
                     # JVM used
-                    THREAD_DUMP => \&exec_thread_dump
+                    THREAD_DUMP => [ "com.bea:Name=examplesServer,ServerRuntime=examplesServer,Type=JRockitRuntime", "ThreadStackDump"]
                    }
      # Alias => [ "mbean", "attribute", "path" ]
     };
 }
 
-sub exec_thread_dump {
-    my $self = shift;
-    my $jmx = $self->{jmx4perl};
-
-    my $beans = $jmx->search("com.bea:Type=JRockitRuntime,*");
-    if ($beans && @{$beans}) {
-        my $bean = $beans->[0];
-        my $request = new JMX::Jmx4Perl::Request(READ,$bean,"ThreadStackDump");
-        return $jmx->request($request);
-    }
-    die $self->name,": Cannot execute THREAD_DUMP because I can't find a suitable JRockitRuntime";
-}
 
 =head1 LICENSE
 
