@@ -10,7 +10,11 @@ sub autodetect {
     return 0;
 }
 
-sub _init_aliases {
+sub order { 
+    return -1;
+}
+
+sub init_aliases {
     return { attributes => 
            {
             MEMORY_HEAP => [ "resolved2_name", "resolved2_attr" ]
